@@ -78,7 +78,7 @@ def userExists(username, hubname = ""):
 
 def _userExists(db, username):
 	sql = 'select id from `jos_users` where username = %s'
-	data = (username)
+	data = [username]
 	userID = db.query_selectscalar(sql, data)
 
 	return userID
@@ -96,7 +96,7 @@ def userLookup(username, hubname = ""):
 
 def _getUserID(db, username):
 	sql = 'select id from `jos_users` where username = %s'
-	data = (username)
+	data = [username]
 
 
 	userID = db.query_selectscalar(sql, data)
@@ -109,11 +109,11 @@ def _getUserID(db, username):
 
 def _del_jos_users(db, username):
 	sql = 'select id from `jos_users` where username = %s'
-	data = (username)
+	data = [username]
 	userID = db.query_selectscalar(sql, data)	
 
 	sql = 'delete from `jos_users` where id = %s'
-	data = (userID)
+	data = [userID]
 	userID = db.query_selectscalar(sql, data)	
 
 	return userID
@@ -121,17 +121,17 @@ def _del_jos_users(db, username):
 def _del_jos_user_usergroup_map(db, userID):
 
 	sql = "DELETE FROM `jos_user_usergroup_map` WHERE `user_id` = %s"
-	data = (userID)
+	data = [userID]
 	db.query_rowcount(sql, data)
 
 def _del_jos_core_acl_aro(db, userID):
 
 	sql = 'select id from `jos_core_acl_aro` where `value` = %s'
-	data = (userID)
+	data = [userID]
 	aroID = db.query_selectscalar(sql, data)	
 
 	sql = "DELETE FROM `jos_core_acl_aro` where `value` = %s"
-	data = (userID)
+	data = [userID]
 	db.query_rowcount(sql, data)
 
 	return aroID
@@ -139,13 +139,13 @@ def _del_jos_core_acl_aro(db, userID):
 
 def _del_jos_core_acl_groups_aro_map(db, aroID):
 	sql = "DELETE FROM `jos_core_acl_groups_aro_map` WHERE `aro_id` = %s"
-	data = (aroID)
+	data = [aroID]
 	db.query_rowcount(sql, data)
 
 
 def _del_jos_xprofiles(db, uidNumber):
 	sql = "DELETE FROM `jos_xprofiles` WHERE `uidNumber` = %s"
-	data = (uidNumber)
+	data = [uidNumber]
 	db.query_rowcount(sql, data)
 
 
@@ -153,7 +153,7 @@ def _update_jos_xprofiles_pw(db, userid, password):
 
 	pw = hashPassword(password)
 	sql = "UPDATE `jos_xprofiles` SET `userPassword`=%s WHERE `uidNumber`=%s"
-	data = (pw, userid)
+	data = [pw, userid]
 	db.query_rowcount(sql, data)
 
 
@@ -161,7 +161,7 @@ def _update_jos_users_pw(db, userid, password):
 
 	pw = hashPassword(password)
 	sql = "UPDATE `jos_users` SET `password` = %s WHERE `id`=%s"
-	data = (pw, userid)
+	data = [pw, userid]
 	db.query_rowcount(sql, data)
 
 
@@ -169,7 +169,7 @@ def _update_jos_users_password(db, userid, password):
 
 	pw = hashPassword(password)
 	sql = "UPDATE `jos_users_password` SET `passhash` = %s WHERE `user_id`=%s"
-	data = (pw, userid)
+	data = [pw, userid]
 	db.query_rowcount(sql, data)
 
 
@@ -228,35 +228,35 @@ def _insert_jos_users(db, joomlauserid, name, username, email, password, jgidNum
 			try:
 				sql =  "INSERT INTO `jos_users` (`name`,`givenName`,`middleName`,`surname`,`username`,`email`,`password`,`usertype`                           ,`block`,`approved`,`sendEmail`,`registerDate`             ,`registerIP`,`lastvisitDate`         ,`activation`,`params`,`lastResetTime`        ,`resetCount`,`access`,`usageAgreement`,`homeDirectory`,`loginShell`,`ftpShell`)"
 				sql += "VALUES (" + "%s,"*22 + '%s' ")"
-				data =                          (name ,firstname  ,middlename  ,lastname ,username  ,email  ,pw        ,userTypeLookupDict[int(jgidNumber)]  , 0     , 1        ,0          , datetime.datetime.now()    ,'127.0.0.1' , '0000-00-00 00:00:00'  ,1           ,''      ,'0000-00-00 00:00:00'  ,0           ,1       ,1               ,''             ,''          ,''      );
+				data =                          [name ,firstname  ,middlename  ,lastname ,username  ,email  ,pw        ,userTypeLookupDict[int(jgidNumber)]  , 0     , 1        ,0          , datetime.datetime.now()    ,'127.0.0.1' , '0000-00-00 00:00:00'  ,1           ,''      ,'0000-00-00 00:00:00'  ,0           ,1       ,1               ,''             ,''          ,''      ];
 				userID = db.query_lastrowid(sql, data)
 			except:
 				sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 				sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-				data = (name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+				data = [name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, datetime.datetime.now(), '0000-00-00 00:00:00', '', ''];
 				userID = db.query_lastrowid(sql, data)
 		else:
 			try:
 				sql =  "INSERT INTO `jos_users` (`id`, `name`,`givenName`,`middleName`,`surname`,`username`,`email`,`password`,`usertype`                           ,`block`,`approved`,`sendEmail`,`registerDate`             ,`registerIP`,`lastvisitDate`         ,`activation`,`params`,`lastResetTime`        ,`resetCount`,`access`,`usageAgreement`,`homeDirectory`,`loginShell`,`ftpShell`)"
 				sql += "VALUES (" + "%s,"*23 + '%s' ")"
-				data =                          (joomlauserid, name ,firstname  ,middlename  ,lastname ,username  ,email  ,pw        ,userTypeLookupDict[int(jgidNumber)]  , 0     , 1        ,0          ,datetime.datetime.now()    ,'127.0.0.1' , '0000-00-00 00:00:00'  ,1           ,''      ,'0000-00-00 00:00:00'  ,0           ,1       ,1               ,''             ,''          ,''      );
+				data =                          [joomlauserid, name ,firstname  ,middlename  ,lastname ,username  ,email  ,pw        ,userTypeLookupDict[int(jgidNumber)]  , 0     , 1        ,0          ,datetime.datetime.now()    ,'127.0.0.1' , '0000-00-00 00:00:00'  ,1           ,''      ,'0000-00-00 00:00:00'  ,0           ,1       ,1               ,''             ,''          ,''      ];
 				userID = db.query_lastrowid(sql, data)
 			except:
 				sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 				sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-				data = (joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+				data = [joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, datetime.datetime.now(), '0000-00-00 00:00:00', '', ''];
 				userID = db.query_lastrowid(sql, data)
 
 	else:
 		if joomlauserid == -1:
 			sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-			data = (name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+			data = [name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', ''];
 			userID = db.query_lastrowid(sql, data)
 		else:
 			sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-			data = (joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber , datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+			data = [joomlauserid, name, username, email, pw, userTypeLookupDict[int(jgidNumber)], 0, 1, jgidNumber , datetime.datetime.now(), '0000-00-00 00:00:00', '', ''];
 			userID = db.query_lastrowid(sql, data)
 
 	return userID
@@ -265,7 +265,7 @@ def _insert_jos_users(db, joomlauserid, name, username, email, password, jgidNum
 def _insert_jos_core_acl_aro(db, userID, fullname):
 	sql = "INSERT INTO `jos_core_acl_aro` (`section_value`, `value`, `order_value`, `name`, `hidden`) "
 	sql += "VALUES (%s, %s, %s, %s, %s)"
-	data = ( 'users',  userID, 0, fullname, 0)
+	data = [ 'users',  userID, 0, fullname, 0]
 	aroID = db.query_lastrowid(sql, data)
 	return aroID
 
@@ -273,13 +273,13 @@ def _insert_jos_core_acl_aro(db, userID, fullname):
 def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	sql = "INSERT INTO `jos_core_acl_groups_aro_map` (`group_id`, `section_value`, `aro_id`) "
 	sql += "VALUES (%s, %s, %s)"
-	data = ( jgidNumber, '', aroID)
+	data = [ jgidNumber, '', aroID]
 	db.query_rowcount(sql, data)
 
 
 def _insert_jos_user_usergroup_map(db, userID, groupID = 2):
 	sql = "INSERT INTO `jos_user_usergroup_map` (`user_id`, `group_id`) VALUES (%s, %s)"
-	data = (userID, groupID)
+	data = [userID, groupID]
 	db.query_rowcount(sql, data)
 
 
@@ -305,10 +305,10 @@ def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username,
 		sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
 		sql += "VALUES (" + '%s,'*37 + "%s );" 
 
-		data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
+		data = [uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
 			    '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
 			    0, tou, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
-			    '', '', fname, mname, lname, '', 0, 0, '', '', None)
+			    '', '', fname, mname, lname, '', 0, 0, '', '', None]
 
 	else:
 		sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
@@ -318,10 +318,10 @@ def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username,
 		sql += "VALUES (" + '%s,'*36 + "%s );" 
 
 
-		data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
+		data = [uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
 			    '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
 			    0, tou, '0000-00-00 00:00:00', 1, '', '', '', '',
-			    '', '', fname, mname, lname, '', 0, 0, '', '', None)
+			    '', '', fname, mname, lname, '', 0, 0, '', '', None]
 
 	db.query_rowcount(sql, data)
 
@@ -337,7 +337,7 @@ def _insert_jos_users_password(db, userid, password):
 	else:
 		pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 
-	data = (userid, pw)
+	data = [userid, pw]
 	db.query_rowcount(sql, data)
 
 
@@ -546,7 +546,7 @@ def addhubuser(hubname,
 		if uidNumber == -1:
 			uidNumber = hubzero.utilities.user.getLDAPMinUIDNumber(hubname, uid_min, uid_max)
 
-		if not createGroup:
+		if createGroup:
 			hubzero.utilities.group.add_ldap_group(username, username + " group", gidNumber)
 
 		add_ldap_user(username, gecos, pw, uidNumber, homeDir, loginShell, gid, gidNumber)
@@ -561,7 +561,7 @@ def delhubuser(username, hubname = ""):
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	sql = 'select id from `jos_users` where username = %s'
-	data = (username)
+	data = [username]
 	userID = db.query_selectscalar(sql, data)
 
 	if userID:
@@ -699,7 +699,7 @@ def _syncuser(username, hubname = "", syncAttributes = False):
 	LEFT JOIN jos_xprofiles AS p ON u.id = p.uidNumber 
 	WHERE u.username = %s; 
 	"""
-	data = (username)
+	data = [username]
 	user = db.query(query, data)
 
 	attrsToSync = {}
